@@ -5,20 +5,19 @@ import (
 	"context"
 	"fmt"
 	json_patch "github.com/evanphx/json-patch/v5"
+	"github.com/kluctl/kluctl/lib/git"
+	gittypes "github.com/kluctl/kluctl/lib/git/types"
+	"github.com/kluctl/kluctl/lib/status"
+	"github.com/kluctl/kluctl/lib/yaml"
 	"github.com/kluctl/kluctl/v2/api/v1beta1"
 	"github.com/kluctl/kluctl/v2/cmd/kluctl/args"
 	"github.com/kluctl/kluctl/v2/pkg/controllers/logs"
-	"github.com/kluctl/kluctl/v2/pkg/git"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/prompts"
 	"github.com/kluctl/kluctl/v2/pkg/results"
 	"github.com/kluctl/kluctl/v2/pkg/sourceoverride"
-	"github.com/kluctl/kluctl/v2/pkg/status"
-	"github.com/kluctl/kluctl/v2/pkg/types"
-	"github.com/kluctl/kluctl/v2/pkg/types/result"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/yaml"
 	flag "github.com/spf13/pflag"
 	v12 "k8s.io/api/core/v1"
 	apiextensionsv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
@@ -58,8 +57,8 @@ type gitopsCmdHelper struct {
 	noArgsReact noArgsReact
 
 	projectGitRoot string
-	projectGitInfo *result.GitInfo
-	projectKey     *result.ProjectKey
+	projectGitInfo *gittypes.GitInfo
+	projectKey     *gittypes.ProjectKey
 
 	kds []v1beta1.KluctlDeployment
 
@@ -106,12 +105,13 @@ func (g *gitopsCmdHelper) init(ctx context.Context) error {
 
 	g.logsBufs = map[logsKey]*logsBuf{}
 
+	loadingRules := clientcmd.NewDefaultClientConfigLoadingRules()
+	loadingRules.ExplicitPath = g.args.Kubeconfig.String()
+
 	configOverrides := &clientcmd.ConfigOverrides{
 		CurrentContext: g.args.Context,
 	}
-	clientConfig := clientcmd.NewNonInteractiveDeferredLoadingClientConfig(
-		clientcmd.NewDefaultClientConfigLoadingRules(),
-		configOverrides)
+	clientConfig := clientcmd.NewNonInteractiveDeferredLoadingClientConfig(loadingRules, configOverrides)
 	restConfig, err := clientConfig.ClientConfig()
 	if err != nil {
 		return err
@@ -231,7 +231,7 @@ func (g *gitopsCmdHelper) collectLocalProjectInfo(ctx context.Context) error {
 		return err
 	}
 
-	if projectKey.RepoKey == (types.RepoKey{}) {
+	if projectKey.RepoKey == (gittypes.RepoKey{}) {
 		return fmt.Errorf("failed to determine repo key")
 	}
 
@@ -277,11 +277,11 @@ func (g *gitopsCmdHelper) autoDetectDeployment(ctx context.Context) error {
 			u = *kd.Spec.Source.URL
 			subDir = kd.Spec.Source.Path
 		}
-		var repoKey types.RepoKey
+		var repoKey gittypes.RepoKey
 		if isGit {
-			repoKey, err = types.NewRepoKeyFromGitUrl(u)
+			repoKey, err = gittypes.NewRepoKeyFromGitUrl(u)
 		} else {
-			repoKey, err = types.NewRepoKeyFromUrl(u)
+			repoKey, err = gittypes.NewRepoKeyFromUrl(u)
 		}
 		if err != nil {
 			status.Warningf(ctx, "Failed to determine repo key for KluctlDeployment %s/%s with source url %s: %s", kd.Namespace, kd.Name, u, err.Error())
