@@ -3,14 +3,15 @@ package commands
 import (
 	"context"
 	"fmt"
+	"github.com/kluctl/kluctl/lib/status"
 	"github.com/kluctl/kluctl/v2/cmd/kluctl/args"
 	"github.com/kluctl/kluctl/v2/pkg/deployment/commands"
-	"github.com/kluctl/kluctl/v2/pkg/status"
 	"time"
 )
 
 type validateCmd struct {
 	args.ProjectFlags
+	args.KubeconfigFlags
 	args.TargetFlags
 	args.ArgsFlags
 	args.InclusionFlags
@@ -33,6 +34,7 @@ TODO: This needs to be better documented!`
 func (cmd *validateCmd) Run(ctx context.Context) error {
 	ptArgs := projectTargetCommandArgs{
 		projectFlags:         cmd.ProjectFlags,
+		kubeconfigFlags:      cmd.KubeconfigFlags,
 		targetFlags:          cmd.TargetFlags,
 		argsFlags:            cmd.ArgsFlags,
 		inclusionFlags:       cmd.InclusionFlags,
@@ -42,7 +44,7 @@ func (cmd *validateCmd) Run(ctx context.Context) error {
 	}
 
 	return withProjectCommandContext(ctx, ptArgs, func(cmdCtx *commandCtx) error {
-		cmd2 := commands.NewValidateCommand("", cmdCtx.targetCtx, nil)
+		cmd2 := commands.NewValidateCommand("", cmdCtx.targetCtx)
 		return cmd.doValidate(cmdCtx, cmd2)
 	})
 }
