@@ -20,6 +20,8 @@ import (
 	"fmt"
 	go_container_logs "github.com/google/go-containerregistry/pkg/logs"
 	"github.com/google/gops/agent"
+	status2 "github.com/kluctl/kluctl/lib/status"
+	"github.com/kluctl/kluctl/lib/yaml"
 	"github.com/kluctl/kluctl/v2/pkg/prompts"
 	flag "github.com/spf13/pflag"
 	"io"
@@ -33,11 +35,9 @@ import (
 	"time"
 
 	"github.com/Masterminds/semver/v3"
-	"github.com/kluctl/kluctl/v2/pkg/status"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
 	"github.com/kluctl/kluctl/v2/pkg/version"
-	"github.com/kluctl/kluctl/v2/pkg/yaml"
 	"github.com/mattn/go-colorable"
 	"github.com/mattn/go-isatty"
 	"github.com/spf13/cobra"
@@ -55,6 +55,8 @@ type GlobalFlags struct {
 	CpuProfile    string `group:"global" help:"Enable CPU profiling and write the result to the given path"`
 	GopsAgent     bool   `group:"global" help:"Start gops agent in the background"`
 	GopsAgentAddr string `group:"global" help:"Specify the address:port to use for the gops agent" default:"127.0.0.1:0"`
+
+	UseSystemPython bool `group:"global" help:"Use the system Python instead of the embedded Python."`
 }
 
 type cli struct {
@@ -70,7 +72,6 @@ type cli struct {
 	PokeImages  pokeImagesCmd  `cmd:"" help:"Replace all images in target"`
 	Prune       pruneCmd       `cmd:"" help:"Searches the target cluster for prunable objects and deletes them"`
 	Render      renderCmd      `cmd:"" help:"Renders all resources and configuration files"`
-	Seal        sealCmd        `cmd:"" help:"Seal secrets based on target's sealingConfig"`
 	Validate    validateCmd    `cmd:"" help:"Validates the already deployed deployment"`
 	Controller  controllerCmd  `cmd:"" help:"Kluctl controller sub-commands"`
 	Gitops      gitopsCmd      `cmd:"" help:"GitOps sub-commands"`
@@ -101,18 +102,18 @@ var origStderr = os.Stderr
 var isTerminal = isatty.IsTerminal(os.Stderr.Fd())
 
 func initStatusHandlerAndPrompts(ctx context.Context, debug bool, noColor bool) context.Context {
-	var sh status.StatusHandler
+	var sh status2.StatusHandler
 	var pp prompts.PromptProvider
 	if !debug && isTerminal {
-		sh = status.NewMultiLineStatusHandler(ctx, origStderr, isTerminal && !noColor, false)
+		sh = status2.NewMultiLineStatusHandler(ctx, origStderr, isTerminal && !noColor, false)
 		pp = &prompts.StatusAndStdinPromptProvider{}
 	} else {
-		sh = status.NewSimpleStatusHandler(func(level status.Level, message string) {
+		sh = status2.NewSimpleStatusHandler(func(level status2.Level, message string) {
 			_, _ = fmt.Fprintf(origStderr, "%s\n", message)
 		}, debug)
 		pp = &prompts.SimplePromptProvider{Out: origStderr}
 	}
-	ctx = status.NewContext(ctx, sh)
+	ctx = status2.NewContext(ctx, sh)
 	ctx = prompts.NewContext(ctx, pp)
 
 	return ctx
@@ -120,19 +121,19 @@ func initStatusHandlerAndPrompts(ctx context.Context, debug bool, noColor bool)
 
 func redirectLogsAndStderr(ctx context.Context) {
 	f := func(line string) {
-		status.Info(ctx, line)
+		status2.Info(ctx, line)
 	}
 
-	lr1 := status.NewLineRedirector(f)
-	lr2 := status.NewLineRedirector(f)
+	lr1 := status2.NewLineRedirector(f)
+	lr2 := status2.NewLineRedirector(f)
 
 	klog.LogToStderr(false)
 	klog.SetOutput(lr1)
 	log.SetOutput(lr2)
 	ctrl.SetLogger(klog.NewKlogr())
 
-	go_container_logs.Warn.SetOutput(status.NewLineRedirector(func(line string) {
-		status.Warning(ctx, line)
+	go_container_logs.Warn.SetOutput(status2.NewLineRedirector(func(line string) {
+		status2.Warning(ctx, line)
 	}))
 
 	pr, pw, err := os.Pipe()
@@ -141,7 +142,7 @@ func redirectLogsAndStderr(ctx context.Context) {
 	}
 
 	go func() {
-		x := status.NewLineRedirector(f)
+		x := status2.NewLineRedirector(f)
 		_, _ = io.Copy(x, pr)
 	}()
 
@@ -187,7 +188,7 @@ func checkNewVersion(ctx context.Context) {
 		return
 	}
 
-	versionCheckPath := filepath.Join(utils.GetTmpBaseDir(ctx), "version_check.yaml")
+	versionCheckPath := filepath.Join(utils.GetCacheDir(ctx), "version_check.yaml")
 	var versionCheckState VersionCheckState
 	err := yaml.ReadYamlFile(versionCheckPath, &versionCheckState)
 	if err == nil {
@@ -199,7 +200,7 @@ func checkNewVersion(ctx context.Context) {
 	versionCheckState.LastVersionCheck = time.Now()
 	_ = yaml.WriteYamlFile(versionCheckPath, &versionCheckState)
 
-	s := status.Start(ctx, "Checking for new kluctl version")
+	s := status2.Start(ctx, "Checking for new kluctl version")
 	defer s.Failed()
 
 	r, err := http.Get(latestReleaseUrl)
@@ -262,7 +263,10 @@ func Main() {
 
 	didSetupStatusHandler := false
 
-	err := Execute(ctx, os.Args[1:], func(ctxIn context.Context, cmd *cobra.Command, flags *GlobalFlags) (context.Context, error) {
+	err := Execute(ctx, os.Args[1:], func(ctxIn context.Context) (context.Context, error) {
+		cmd := getCobraCommand(ctxIn)
+		flags := getCobraGlobalFlags(ctxIn)
+
 		err := setupGops(flags)
 		if err != nil {
 			return ctx, err
@@ -295,13 +299,13 @@ func Main() {
 
 	if err != nil {
 		if didSetupStatusHandler {
-			status.Error(ctx, err.Error())
+			status2.Error(ctx, err.Error())
 		} else {
 			_, _ = fmt.Fprintf(os.Stderr, "%s\n", err.Error())
 		}
 	}
 
-	sh := status.FromContext(ctx)
+	sh := status2.FromContext(ctx)
 	if sh != nil {
 		sh.Stop()
 	}
@@ -312,6 +316,7 @@ func Main() {
 }
 
 type cobraCmdContextKey struct{}
+type cobraGlobalFlagsKey struct{}
 
 func getCobraCommand(ctx context.Context) *cobra.Command {
 	v := ctx.Value(cobraCmdContextKey{})
@@ -321,7 +326,15 @@ func getCobraCommand(ctx context.Context) *cobra.Command {
 	return nil
 }
 
-func Execute(ctx context.Context, args []string, preRun func(ctx context.Context, rootCmd *cobra.Command, flags *GlobalFlags) (context.Context, error)) error {
+func getCobraGlobalFlags(ctx context.Context) *GlobalFlags {
+	v := ctx.Value(cobraGlobalFlagsKey{})
+	if x, ok := v.(*GlobalFlags); ok {
+		return x
+	}
+	panic("missing global flags")
+}
+
+func Execute(ctx context.Context, args []string, preRun func(ctx context.Context) (context.Context, error)) error {
 	root := cli{}
 	rootCmd, err := buildRootCobraCmd(&root, "kluctl",
 		"Deploy and manage complex deployments on Kubernetes",
@@ -350,8 +363,13 @@ composed of multiple smaller parts (Helm/Kustomize/...) in a manageable and unif
 			return err
 		}
 
+		ctx = context.WithValue(ctx, cobraGlobalFlagsKey{}, &root.GlobalFlags)
+		for c := cmd; c != nil; c = c.Parent() {
+			c.SetContext(ctx)
+		}
+
 		if preRun != nil {
-			ctx, err = preRun(ctx, cmd, &root.GlobalFlags)
+			ctx, err = preRun(ctx)
 			if ctx != nil {
 				for c := cmd; c != nil; c = c.Parent() {
 					c.SetContext(ctx)
