@@ -33,7 +33,7 @@ func (suite *GitOpsIncludesSuite) TestGitOpsGitIncludeDeprecatedSecret() {
 	p, _, _ := prepareGitIncludeTest(suite.T(), suite.k, mainGs, gs1, gs2)
 
 	key := suite.createKluctlDeployment2(p, "test", nil, func(kd *v1beta1.KluctlDeployment) {
-		kd.Spec.Source.URL = utils.StrPtr(p.GitUrl())
+		kd.Spec.Source.URL = utils.Ptr(p.GitUrl())
 	})
 
 	suite.Run("fail without authentication", func() {
@@ -45,7 +45,7 @@ func (suite *GitOpsIncludesSuite) TestGitOpsGitIncludeDeprecatedSecret() {
 		g.Expect(readinessCondition).ToNot(BeNil())
 		g.Expect(readinessCondition.Status).To(Equal(v1.ConditionFalse))
 		g.Expect(readinessCondition.Reason).To(Equal("PrepareFailed"))
-		g.Expect(readinessCondition.Message).To(Equal("failed to clone git source: authentication required"))
+		g.Expect(kd.Status.LastPrepareError).To(Equal("failed to clone git source: authentication required"))
 	})
 
 	secret := corev1.Secret{
@@ -87,7 +87,7 @@ func (suite *GitOpsIncludesSuite) testGitOpsGitIncludeCredentials(legacyGitSourc
 	var key client.ObjectKey
 	if legacyGitSource {
 		key = suite.createKluctlDeployment2(p, "test", nil, func(kd *v1beta1.KluctlDeployment) {
-			kd.Spec.Source.URL = utils.StrPtr(p.GitUrl())
+			kd.Spec.Source.URL = utils.Ptr(p.GitUrl())
 		})
 	} else {
 		key = suite.createKluctlDeployment(p, "test", nil)
@@ -102,7 +102,7 @@ func (suite *GitOpsIncludesSuite) testGitOpsGitIncludeCredentials(legacyGitSourc
 		g.Expect(readinessCondition).ToNot(BeNil())
 		g.Expect(readinessCondition.Status).To(Equal(v1.ConditionFalse))
 		g.Expect(readinessCondition.Reason).To(Equal("PrepareFailed"))
-		g.Expect(readinessCondition.Message).To(Equal("failed to clone git source: authentication required"))
+		g.Expect(kd.Status.LastPrepareError).To(Equal("failed to clone git source: authentication required"))
 	})
 
 	createSecret := func(username string, password string) string {
@@ -120,7 +120,7 @@ func (suite *GitOpsIncludesSuite) testGitOpsGitIncludeCredentials(legacyGitSourc
 			var credentials []v1beta1.ProjectCredentialsGitDeprecated
 			credentials = append(credentials, v1beta1.ProjectCredentialsGitDeprecated{
 				Host:       gs1.GitHost(),
-				PathPrefix: ip1.GitRepoName(),
+				PathPrefix: ip1.GitUrlPath(),
 				SecretRef:  v1beta1.LocalObjectReference{Name: secret2},
 			})
 			credentials = append(credentials, v1beta1.ProjectCredentialsGitDeprecated{
@@ -137,7 +137,7 @@ func (suite *GitOpsIncludesSuite) testGitOpsGitIncludeCredentials(legacyGitSourc
 			var credentials []v1beta1.ProjectCredentialsGit
 			credentials = append(credentials, v1beta1.ProjectCredentialsGit{
 				Host:      gs1.GitHost(),
-				Path:      ip1.GitRepoName(),
+				Path:      ip1.GitUrlPath(),
 				SecretRef: v1beta1.LocalObjectReference{Name: secret2},
 			})
 			credentials = append(credentials, v1beta1.ProjectCredentialsGit{
