@@ -38,7 +38,8 @@ type helmTestCase struct {
 	argPassCA         bool
 	argPassClientCert bool
 
-	expectedError string
+	expectedReadyError   string
+	expectedPrepareError string
 }
 
 var helmTests = []helmTestCase{
@@ -48,9 +49,10 @@ var helmTests = []helmTestCase{
 	// tls tests
 	{
 		name: "helm-tls-missing-ca", testTLS: true,
-		argPassCA:     false,
-		argCredsHost:  "<host>",
-		expectedError: "failed to verify certificate",
+		argPassCA:            false,
+		argCredsHost:         "<host>",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "failed to verify certificate",
 	},
 	{
 		name: "helm-tls-valid-ca", testTLS: true,
@@ -59,10 +61,11 @@ var helmTests = []helmTestCase{
 	},
 	{
 		name: "helm-tls-missing-cert", testTLS: true, testTLSClientCert: true,
-		argPassCA:         true,
-		argPassClientCert: false,
-		argCredsHost:      "<host>",
-		expectedError:     "certificate required",
+		argPassCA:            true,
+		argPassClientCert:    false,
+		argCredsHost:         "<host>",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "certificate required",
 	},
 	{
 		name: "helm-tls-valid-cert", testTLS: true, testTLSClientCert: true,
@@ -73,9 +76,10 @@ var helmTests = []helmTestCase{
 
 	{
 		name: "oci-tls-missing-ca", oci: true, testTLS: true,
-		argPassCA:     false,
-		argCredsHost:  "<host>",
-		expectedError: "failed to verify certificate",
+		argPassCA:            false,
+		argCredsHost:         "<host>",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "failed to verify certificate",
 	},
 	{
 		name: "oci-tls-valid-ca", oci: true, testTLS: true,
@@ -84,10 +88,11 @@ var helmTests = []helmTestCase{
 	},
 	{
 		name: "oci-tls-missing-cert", oci: true, testTLS: true, testTLSClientCert: true,
-		argPassCA:         true,
-		argPassClientCert: false,
-		argCredsHost:      "<host>",
-		expectedError:     "certificate required",
+		argPassCA:            true,
+		argPassClientCert:    false,
+		argCredsHost:         "<host>",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "certificate required",
 	},
 	{
 		name: "oci-tls-valid-cert", oci: true, testTLS: true, testTLSClientCert: true,
@@ -99,12 +104,14 @@ var helmTests = []helmTestCase{
 	// deprecated helm credentials flags
 	{
 		name: "dep-helm-creds-missing", oci: false, testAuth: true, credsId: "test-creds",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "dep-helm-creds-invalid", oci: false, testAuth: true, credsId: "test-creds",
 		argCredsId: "test-creds", argUsername: "test-user", argPassword: "invalid",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "dep-helm-creds-valid", oci: false, testAuth: true, credsId: "test-creds",
@@ -113,19 +120,22 @@ var helmTests = []helmTestCase{
 	{
 		name: "dep-oci-creds-fail", oci: true, testAuth: true, credsId: "test-creds",
 		argCredsId: "test-creds", argUsername: "test-user", argPassword: "secret-password",
-		expectedError: "OCI charts can currently only be authenticated via registry login and environment variables but not via cli arguments",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "OCI charts can currently only be authenticated via registry login and environment variables but not via cli arguments",
 	},
 
 	// new helm credentials flags
 	{
 		name: "helm-creds-missing", oci: false, testAuth: true,
 		argCredsHost: "<host>-invalid", argUsername: "test-user", argPassword: "secret-password",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "helm-creds-invalid", oci: false, testAuth: true,
 		argCredsHost: "<host>", argUsername: "test-user", argPassword: "invalid",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "helm-creds-valid", oci: false, testAuth: true,
@@ -134,12 +144,14 @@ var helmTests = []helmTestCase{
 	{
 		name: "helm-creds-missing-path", oci: false, testAuth: true, path: "path1",
 		argCredsHost: "<host>", argCredsPath: "path2", argUsername: "test-user", argPassword: "secret-password",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "helm-creds-invalid-path", oci: false, testAuth: true, path: "path1",
 		argCredsHost: "<host>", argCredsPath: "path1", argUsername: "test-user", argPassword: "invalid",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "helm-creds-valid-path", oci: false, testAuth: true, path: "path1",
@@ -150,12 +162,14 @@ var helmTests = []helmTestCase{
 	{
 		name: "oci-creds-missing", oci: true, testAuth: true,
 		argCredsHost: "<host>-invalid", argUsername: "test-user", argPassword: "secret-password",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "no basic auth credentials",
 	},
 	{
 		name: "oci-creds-invalid", oci: true, testAuth: true,
 		argCredsHost: "<host>", argUsername: "test-user", argPassword: "invalid",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "oci-creds-valid", oci: true, testAuth: true,
@@ -164,12 +178,14 @@ var helmTests = []helmTestCase{
 	{
 		name: "oci-creds-missing-path", oci: true, testAuth: true,
 		argCredsHost: "<host>", argCredsPath: "test-chart2", argUsername: "test-user", argPassword: "secret-password",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "no basic auth credentials",
 	},
 	{
 		name: "oci-creds-invalid-path", oci: true, testAuth: true,
 		argCredsHost: "<host>", argCredsPath: "test-chart1", argUsername: "test-user", argPassword: "invalid",
-		expectedError: "401 Unauthorized",
+		expectedReadyError:   "prepare failed with 1 errors. Check status.lastPrepareError for details",
+		expectedPrepareError: "401 Unauthorized",
 	},
 	{
 		name: "oci-creds-valid-path", oci: true, testAuth: true,
@@ -314,8 +330,30 @@ func buildHelmTestEnvVars(t *testing.T, tc helmTestCase, p *test_project.TestPro
 	}
 }
 
-func prepareHelmTestCase(t *testing.T, k *test_utils.EnvTestCluster, tc helmTestCase, prePull bool, useProcess bool) (*test_project.TestProject, *test_utils.TestHelmRepo, error) {
-	p := test_project.NewTestProject(t, test_project.WithUseProcess(useProcess))
+func prepareHelmTestCase(t *testing.T, k *test_utils.EnvTestCluster, tc helmTestCase, prePull bool, useProcess bool, libraryMode libraryTestMode) (*test_project.TestProject, *test_utils.TestHelmRepo, error) {
+	gitServer := test_utils.NewTestGitServer(t)
+	gitSubDir := ""
+
+	if libraryMode == includeLibrary {
+		gitSubDir = "include"
+	}
+
+	p := test_project.NewTestProject(t,
+		test_project.WithUseProcess(useProcess),
+		test_project.WithBareProject(),
+		test_project.WithGitServer(gitServer),
+		test_project.WithGitSubDir(gitSubDir),
+	)
+
+	if libraryMode != noLibrary {
+		p.UpdateYaml(".kluctl-library.yaml", func(o *uo.UnstructuredObject) error {
+			return nil
+		}, "")
+	} else {
+		p.UpdateKluctlYaml(func(o *uo.UnstructuredObject) error {
+			return nil
+		})
+	}
 
 	createNamespace(t, k, p.TestSlug())
 
@@ -344,7 +382,6 @@ func prepareHelmTestCase(t *testing.T, k *test_utils.EnvTestCluster, tc helmTest
 
 	extraArgs := buildHelmTestExtraArgs(t, tc, repo)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
 
 	if tc.testAuth {
@@ -361,15 +398,15 @@ func prepareHelmTestCase(t *testing.T, k *test_utils.EnvTestCluster, tc helmTest
 		args = append(args, extraArgs...)
 
 		_, stderr, err := p.Kluctl(t, args...)
-		if tc.expectedError != "" {
+		if tc.expectedPrepareError != "" {
 			assert.Error(t, err)
-			assert.Contains(t, stderr, tc.expectedError)
+			assert.Contains(t, stderr, tc.expectedPrepareError)
 			return p, repo, err
 		} else {
 			assert.NoError(t, err)
 			assert.FileExists(t, getChartFile(t, p, repo.URL.String(), "test-chart1", "0.1.0"))
 
-			p.GitServer().CommitFiles(p.GitRepoName(), []string{".helm-charts"}, true, "helm-pull")
+			p.GitServer().CommitFiles(p.GitRepoName(), []string{filepath.Join(gitSubDir, ".helm-charts")}, true, "helm-pull")
 		}
 	} else {
 		p.UpdateYaml("helm1/helm-chart.yaml", func(o *uo.UnstructuredObject) error {
@@ -378,10 +415,42 @@ func prepareHelmTestCase(t *testing.T, k *test_utils.EnvTestCluster, tc helmTest
 		}, "")
 	}
 
+	if libraryMode == gitLibrary {
+		p2 := test_project.NewTestProject(t,
+			test_project.WithUseProcess(useProcess),
+			test_project.WithBareProject(),
+		)
+		p2.AddDeploymentItem("", uo.FromMap(map[string]interface{}{
+			"git": map[string]any{
+				"url": p.GitUrl(),
+			},
+		}))
+		return p2, repo, nil
+	} else if libraryMode == includeLibrary {
+		p2 := test_project.NewTestProject(t,
+			test_project.WithUseProcess(useProcess),
+			test_project.WithBareProject(),
+			test_project.WithGitServer(gitServer),
+			test_project.WithGitSubDir("project"),
+		)
+		p2.AddDeploymentItem("", uo.FromMap(map[string]interface{}{
+			"include": "../include",
+		}))
+		return p2, repo, nil
+	}
+
 	return p, repo, nil
 }
 
-func testHelmPull(t *testing.T, tc helmTestCase, prePull bool, credsViaEnv bool) {
+type libraryTestMode int
+
+const (
+	noLibrary = iota
+	gitLibrary
+	includeLibrary
+)
+
+func testHelmPull(t *testing.T, tc helmTestCase, prePull bool, credsViaEnv bool, libraryMode libraryTestMode) {
 	useProcess := credsViaEnv
 
 	// uncomment this if you want to debug this when credsViaEnv==true
@@ -392,15 +461,15 @@ func testHelmPull(t *testing.T, tc helmTestCase, prePull bool, credsViaEnv bool)
 	}
 
 	k := defaultCluster1
-	p, repo, err := prepareHelmTestCase(t, k, tc, prePull, useProcess)
+	p, repo, err := prepareHelmTestCase(t, k, tc, prePull, useProcess, libraryMode)
 	if err != nil {
-		if tc.expectedError == "" {
+		if tc.expectedPrepareError == "" {
 			assert.Fail(t, "did not expect error")
 		}
 		return
 	}
 
-	args := []string{"deploy", "--yes", "-t", "test"}
+	args := []string{"deploy", "--yes"}
 	if credsViaEnv {
 		buildHelmTestEnvVars(t, tc, p, repo)
 	} else {
@@ -414,11 +483,11 @@ func testHelmPull(t *testing.T, tc helmTestCase, prePull bool, credsViaEnv bool)
 	} else {
 		assert.Contains(t, stderr, pullMessage)
 	}
-	if tc.expectedError != "" {
+	if tc.expectedPrepareError != "" {
 		if useProcess {
-			assert.Contains(t, stderr, tc.expectedError)
+			assert.Contains(t, stderr, tc.expectedPrepareError)
 		} else {
-			assert.ErrorContains(t, err, tc.expectedError)
+			assert.ErrorContains(t, err, tc.expectedPrepareError)
 		}
 	} else {
 		assert.NoError(t, err)
@@ -430,7 +499,7 @@ func TestHelmPull(t *testing.T) {
 	for _, tc := range helmTests {
 		tc := tc
 		t.Run(tc.name, func(t *testing.T) {
-			testHelmPull(t, tc, false, false)
+			testHelmPull(t, tc, false, false, noLibrary)
 		})
 	}
 }
@@ -439,7 +508,7 @@ func TestHelmPrePull(t *testing.T) {
 	for _, tc := range helmTests {
 		tc := tc
 		t.Run(tc.name, func(t *testing.T) {
-			testHelmPull(t, tc, true, false)
+			testHelmPull(t, tc, true, false, noLibrary)
 		})
 	}
 }
@@ -448,7 +517,25 @@ func TestHelmPullCredsViaEnv(t *testing.T) {
 	for _, tc := range helmTests {
 		tc := tc
 		t.Run(tc.name, func(t *testing.T) {
-			testHelmPull(t, tc, false, true)
+			testHelmPull(t, tc, false, true, noLibrary)
+		})
+	}
+}
+
+func TestHelmInGitLibrary(t *testing.T) {
+	for _, tc := range helmTests {
+		tc := tc
+		t.Run(tc.name, func(t *testing.T) {
+			testHelmPull(t, tc, true, false, gitLibrary)
+		})
+	}
+}
+
+func TestHelmInIncludeLibrary(t *testing.T) {
+	for _, tc := range helmTests {
+		tc := tc
+		t.Run(tc.name, func(t *testing.T) {
+			testHelmPull(t, tc, true, false, includeLibrary)
 		})
 	}
 }
@@ -471,12 +558,11 @@ func testHelmManualUpgrade(t *testing.T, oci bool) {
 	}
 	repo.Start(t)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
 
 	p.KluctlMust(t, "helm-pull")
 	assert.FileExists(t, getChartFile(t, p, repo.URL.String(), "test-chart1", "0.1.0"))
-	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes")
 	cm := assertConfigMapExists(t, k, p.TestSlug(), "test-helm1-test-chart1")
 	v, _, _ := cm.GetNestedString("data", "version")
 	assert.Equal(t, "0.1.0", v)
@@ -489,7 +575,7 @@ func testHelmManualUpgrade(t *testing.T, oci bool) {
 	p.KluctlMust(t, "helm-pull")
 	assert.NoFileExists(t, getChartFile(t, p, repo.URL.String(), "test-chart1", "0.1.0"))
 	assert.FileExists(t, getChartFile(t, p, repo.URL.String(), "test-chart1", "0.2.0"))
-	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes")
 	cm = assertConfigMapExists(t, k, p.TestSlug(), "test-helm1-test-chart1")
 	v, _, _ = cm.GetNestedString("data", "version")
 	assert.Equal(t, "0.2.0", v)
@@ -523,7 +609,6 @@ func testHelmUpdate(t *testing.T, oci bool, upgrade bool, commit bool) {
 	}
 	repo.Start(t)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm2", repo.URL.String(), "test-chart2", "0.1.0", "test-helm2", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm3", repo.URL.String(), "test-chart1", "0.1.0", "test-helm3", p.TestSlug(), nil)
@@ -552,8 +637,8 @@ func testHelmUpdate(t *testing.T, oci bool, upgrade bool, commit bool) {
 	}
 
 	_, stderr := p.KluctlMust(t, args...)
-	assert.Contains(t, stderr, "helm1: Chart test-chart1 has new version 0.2.0 available")
-	assert.Contains(t, stderr, "helm2: Chart test-chart2 has new version 0.3.0 available")
+	assert.Contains(t, stderr, "helm1: Chart test-chart1 (old version 0.1.0) has new version 0.2.0 available")
+	assert.Contains(t, stderr, "helm2: Chart test-chart2 (old version 0.1.0) has new version 0.3.0 available")
 	assert.Contains(t, stderr, "helm3: Skipped update to version 0.2.0")
 
 	if upgrade {
@@ -644,7 +729,6 @@ func testHelmUpdateConstraints(t *testing.T, oci bool) {
 	}
 	repo.Start(t)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm2", repo.URL.String(), "test-chart1", "0.1.0", "test-helm2", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm3", repo.URL.String(), "test-chart1", "0.1.0", "test-helm3", p.TestSlug(), nil)
@@ -665,9 +749,9 @@ func testHelmUpdateConstraints(t *testing.T, oci bool) {
 	args := []string{"helm-update", "--upgrade"}
 
 	_, stderr := p.KluctlMust(t, args...)
-	assert.Contains(t, stderr, "helm1: Chart test-chart1 has new version 0.1.1 available")
-	assert.Contains(t, stderr, "helm2: Chart test-chart1 has new version 0.2.0 available")
-	assert.Contains(t, stderr, "helm3: Chart test-chart1 has new version 1.2.1 available")
+	assert.Contains(t, stderr, "helm1: Chart test-chart1 (old version 0.1.0) has new version 0.1.1 available")
+	assert.Contains(t, stderr, "helm2: Chart test-chart1 (old version 0.1.0) has new version 0.2.0 available")
+	assert.Contains(t, stderr, "helm3: Chart test-chart1 (old version 0.1.0) has new version 1.2.1 available")
 
 	c1 := p.GetYaml("helm1/helm-chart.yaml")
 	c2 := p.GetYaml("helm2/helm-chart.yaml")
@@ -725,13 +809,12 @@ func TestHelmValues(t *testing.T) {
 		},
 	}
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), values1)
 	p.AddHelmDeployment("helm2", repo.URL.String(), "test-chart2", "0.1.0", "test-helm2", p.TestSlug(), values2)
 	p.AddHelmDeployment("helm3", repo.URL.String(), "test-chart1", "0.1.0", "test-helm3", p.TestSlug(), values3)
 
 	p.KluctlMust(t, "helm-pull")
-	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-aa=a", "-ab=b")
+	p.KluctlMust(t, "deploy", "--yes", "-aa=a", "-ab=b")
 
 	cm1 := assertConfigMapExists(t, k, p.TestSlug(), "test-helm1-test-chart1")
 	cm2 := assertConfigMapExists(t, k, p.TestSlug(), "test-helm2-test-chart2")
@@ -776,14 +859,13 @@ func TestHelmTemplateChartYaml(t *testing.T) {
 	}
 	repo.Start(t)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm-{{ args.a }}", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm2", repo.URL.String(), "test-chart2", "0.1.0", "test-helm-{{ args.b }}", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm3", repo.URL.String(), "test-chart1", "0.1.0", "test-helm-ns", p.TestSlug()+"-{{ args.a }}", nil)
 	p.AddHelmDeployment("helm4", repo.URL.String(), "test-chart1", "0.1.0", "test-helm-ns", p.TestSlug()+"-{{ args.b }}", nil)
 
 	p.KluctlMust(t, "helm-pull")
-	p.KluctlMust(t, "deploy", "--yes", "-t", "test", "-aa=a", "-ab=b")
+	p.KluctlMust(t, "deploy", "--yes", "-aa=a", "-ab=b")
 
 	assertConfigMapExists(t, k, p.TestSlug(), "test-helm-a-test-chart1")
 	assertConfigMapExists(t, k, p.TestSlug(), "test-helm-b-test-chart2")
@@ -807,14 +889,13 @@ func TestHelmRenderOfflineKubernetes(t *testing.T) {
 	}
 	repo.Start(t)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
 	p.UpdateYaml("helm1/helm-chart.yaml", func(o *uo.UnstructuredObject) error {
 		_ = o.SetNestedField(true, "helmChart", "skipPrePull")
 		return nil
 	}, "")
 
-	stdout, _ := p.KluctlMust(t, "render", "--print-all", "--offline-kubernetes", "-t", "test")
+	stdout, _ := p.KluctlMust(t, "render", "--print-all", "--offline-kubernetes")
 	cm1 := uo.FromStringMust(stdout)
 
 	assert.Equal(t, map[string]any{
@@ -824,7 +905,7 @@ func TestHelmRenderOfflineKubernetes(t *testing.T) {
 		"kubeVersion": "v1.20.0",
 	}, cm1.Object["data"])
 
-	stdout, _ = p.KluctlMust(t, "render", "--print-all", "--offline-kubernetes", "--kubernetes-version", "1.22.1", "-t", "test")
+	stdout, _ = p.KluctlMust(t, "render", "--print-all", "--offline-kubernetes", "--kubernetes-version", "1.22.1")
 	cm1 = uo.FromStringMust(stdout)
 
 	assert.Equal(t, map[string]any{
@@ -844,14 +925,13 @@ func TestHelmLocalChart(t *testing.T) {
 
 	createNamespace(t, k, p.TestSlug())
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", "../test-chart1", "", "", "test-helm-1", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm2", "test-chart2", "", "", "test-helm-2", p.TestSlug(), nil)
 
 	test_utils.CreateHelmDir(t, "test-chart1", "0.1.0", filepath.Join(p.LocalProjectDir(), "test-chart1"))
 	test_utils.CreateHelmDir(t, "test-chart2", "0.1.0", filepath.Join(p.LocalProjectDir(), "helm2/test-chart2"))
 
-	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes")
 	assertConfigMapExists(t, k, p.TestSlug(), "test-helm-1-test-chart1")
 	assertConfigMapExists(t, k, p.TestSlug(), "test-helm-2-test-chart2")
 
@@ -878,7 +958,6 @@ func TestHelmSkipPrePull(t *testing.T) {
 	}
 	repo.Start(t)
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
 	p.AddHelmDeployment("helm2", repo.URL.String(), "test-chart1", "0.1.1", "test-helm2", p.TestSlug(), nil)
 
@@ -1013,22 +1092,46 @@ func TestHelmLookup(t *testing.T) {
 		"lookupName":      lookupCm.Name,
 	}
 
-	p.UpdateTarget("test", nil)
 	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), values1)
 
 	p.KluctlMust(t, "helm-pull")
-	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
+	p.KluctlMust(t, "deploy", "--yes")
 
 	cm1 := assertConfigMapExists(t, k, p.TestSlug(), "test-helm1-test-chart1")
 	assertNestedFieldEquals(t, cm1, "lookupValue", "data", "lookup")
 
-	s, _ := p.KluctlMust(t, "render", "-t", "test", "--print-all")
+	s, _ := p.KluctlMust(t, "render", "--print-all")
 	y, err := uo.FromString(s)
 	assert.NoError(t, err)
 	assertNestedFieldEquals(t, y, "lookupValue", "data", "lookup")
 
-	s, _ = p.KluctlMust(t, "render", "-t", "test", "--print-all", "--offline-kubernetes")
+	s, _ = p.KluctlMust(t, "render", "--print-all", "--offline-kubernetes")
 	y, err = uo.FromString(s)
 	assert.NoError(t, err)
 	assertNestedFieldEquals(t, y, "lookupReturnedNil", "data", "lookup")
 }
+
+func TestHelmWithTarget(t *testing.T) {
+	t.Parallel()
+
+	k := defaultCluster1
+
+	p := test_project.NewTestProject(t)
+	p.UpdateTarget("test", nil)
+
+	createNamespace(t, k, p.TestSlug())
+
+	repo := &test_utils.TestHelmRepo{
+		Charts: []test_utils.RepoChart{
+			{ChartName: "test-chart1", Version: "0.1.0"},
+		},
+	}
+	repo.Start(t)
+
+	p.AddHelmDeployment("helm1", repo.URL.String(), "test-chart1", "0.1.0", "test-helm1", p.TestSlug(), nil)
+
+	p.KluctlMust(t, "helm-pull")
+	p.KluctlMust(t, "deploy", "--yes", "-t", "test")
+
+	assertConfigMapExists(t, k, p.TestSlug(), "test-helm1-test-chart1")
+}
