@@ -6,10 +6,12 @@ import (
 	"github.com/go-git/go-git/v5"
 	"github.com/huandu/xstrings"
 	"github.com/jinzhu/copier"
+	gittypes "github.com/kluctl/kluctl/lib/git/types"
+	"github.com/kluctl/kluctl/lib/yaml"
 	git2 "github.com/kluctl/kluctl/v2/e2e/test-utils"
+	"github.com/kluctl/kluctl/v2/pkg/types/result"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
 	"github.com/kluctl/kluctl/v2/pkg/utils/uo"
-	"github.com/kluctl/kluctl/v2/pkg/yaml"
 	cp "github.com/otiai10/copy"
 	registry2 "helm.sh/helm/v3/pkg/registry"
 	"net/url"
@@ -25,6 +27,9 @@ import (
 type TestProject struct {
 	initialName string
 
+	tmpBaseDir string
+	cacheDir   string
+
 	extraEnv          utils.OrderedMap[string, string]
 	extraArgs         []string
 	useProcess        bool
@@ -38,6 +43,18 @@ type TestProject struct {
 
 type TestProjectOption func(p *TestProject)
 
+func WithTmpBaseDir(baseDir string) TestProjectOption {
+	return func(p *TestProject) {
+		p.tmpBaseDir = baseDir
+	}
+}
+
+func WithCacheDir(dir string) TestProjectOption {
+	return func(p *TestProject) {
+		p.cacheDir = dir
+	}
+}
+
 func WithUseProcess(useProcess bool) TestProjectOption {
 	return func(p *TestProject) {
 		p.useProcess = useProcess
@@ -84,10 +101,19 @@ func NewTestProject(t *testing.T, opts ...TestProjectOption) *TestProject {
 		o(p)
 	}
 
+	if p.tmpBaseDir == "" {
+		p.tmpBaseDir = t.TempDir()
+	}
+	if p.cacheDir == "" {
+		p.cacheDir = t.TempDir()
+	}
+
 	if p.gitServer == nil {
 		p.gitServer = git2.NewTestGitServer(t)
 	}
-	p.gitServer.GitInit(p.gitRepoName)
+	if !utils.IsDirectory(p.gitServer.LocalWorkDir(p.gitRepoName)) {
+		p.gitServer.GitInit(p.gitRepoName)
+	}
 
 	if !p.bare {
 		p.UpdateKluctlYaml(func(o *uo.UnstructuredObject) error {
@@ -452,12 +478,20 @@ func (p *TestProject) GitUrl() string {
 	return p.gitServer.GitRepoUrl(p.gitRepoName)
 }
 
-func (p *TestProject) LocalRepoDir() string {
-	return p.gitServer.LocalRepoDir(p.gitRepoName)
+func (p *TestProject) GitUrlPath() string {
+	u, err := gittypes.ParseGitUrl(p.GitUrl())
+	if err != nil {
+		panic(err)
+	}
+	return strings.TrimPrefix(u.Path, "/")
+}
+
+func (p *TestProject) LocalWorkDir() string {
+	return p.gitServer.LocalWorkDir(p.gitRepoName)
 }
 
 func (p *TestProject) LocalProjectDir() string {
-	return path.Join(p.LocalRepoDir(), p.gitSubDir)
+	return path.Join(p.LocalWorkDir(), p.gitSubDir)
 }
 
 func (p *TestProject) GetGitRepo() *git.Repository {
@@ -473,7 +507,7 @@ func (p *TestProject) GetGitWorktree() *git.Worktree {
 }
 
 func (p *TestProject) CopyProjectSourceTo(dst string) string {
-	err := cp.Copy(p.LocalRepoDir(), dst)
+	err := cp.Copy(p.LocalWorkDir(), dst)
 	if err != nil {
 		panic(err)
 	}
@@ -497,7 +531,8 @@ func (p *TestProject) KluctlProcess(t *testing.T, argsIn ...string) (string, str
 
 	// this will cause the init() function from call_kluctl_hack.go to invoke the kluctl root command and then exit
 	env = append(env, "CALL_KLUCTL=true")
-	env = append(env, fmt.Sprintf("KLUCTL_BASE_TMP_DIR=%s", t.TempDir()))
+	env = append(env, fmt.Sprintf("KLUCTL_BASE_TMP_DIR=%s", p.tmpBaseDir))
+	env = append(env, fmt.Sprintf("KLUCTL_CACHE_DIR=%s", p.cacheDir))
 
 	t.Logf("Runnning kluctl: %s", strings.Join(args, " "))
 
@@ -535,7 +570,15 @@ func (p *TestProject) KluctlExecute(t *testing.T, argsIn ...string) (string, str
 	}
 	args = append(args, argsIn...)
 
-	return KluctlExecute(t, context.Background(), t.Log, args...)
+	ctx := context.Background()
+	if p.tmpBaseDir != "" {
+		ctx = utils.WithTmpBaseDir(ctx, p.tmpBaseDir)
+	}
+	if p.cacheDir != "" {
+		ctx = utils.WithCacheDir(ctx, p.cacheDir)
+	}
+
+	return KluctlExecute(t, ctx, t.Log, args...)
 }
 
 func (p *TestProject) Kluctl(t *testing.T, argsIn ...string) (string, string, error) {
@@ -553,3 +596,26 @@ func (p *TestProject) KluctlMust(t *testing.T, argsIn ...string) (string, string
 	}
 	return stdout, stderr
 }
+
+func (p *TestProject) KluctlCommandResult(t *testing.T, argsIn ...string) (*result.CommandResult, string, error) {
+	stdout, stderr, err := p.Kluctl(t, argsIn...)
+	if err != nil {
+		return nil, "", err
+	}
+
+	var ret result.CompactedCommandResult
+	err = yaml.ReadYamlString(stdout, &ret)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	return ret.ToNonCompacted(), stderr, nil
+}
+
+func (p *TestProject) KluctlMustCommandResult(t *testing.T, argsIn ...string) (*result.CommandResult, string) {
+	ret, stderr, err := p.KluctlCommandResult(t, argsIn...)
+	if err != nil {
+		t.Fatal(err)
+	}
+	return ret, stderr
+}
