@@ -1,12 +1,13 @@
 package commands
 
 import (
+	"github.com/kluctl/kluctl/lib/git"
 	utils2 "github.com/kluctl/kluctl/v2/pkg/deployment/utils"
-	"github.com/kluctl/kluctl/v2/pkg/git"
 	k8s2 "github.com/kluctl/kluctl/v2/pkg/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/kluctl_project/target-context"
 	"github.com/kluctl/kluctl/v2/pkg/types/result"
 	"github.com/kluctl/kluctl/v2/pkg/utils"
+	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"time"
 )
@@ -40,11 +41,8 @@ func newCommandResult(targetCtx *target_context.TargetContext, startTime time.Ti
 		})
 	}
 
-	r.ClusterInfo, err = buildClusterInfo(targetCtx.SharedContext.K)
-	if err != nil {
-		r.Errors = append(r.Errors, result.DeploymentError{
-			Message: err.Error(),
-		})
+	if targetCtx.SharedContext.K != nil {
+		r.ClusterInfo = buildClusterInfo(targetCtx.SharedContext.K, &r.Warnings)
 	}
 
 	r.TargetKey.TargetName = targetCtx.Target.Name
@@ -68,16 +66,13 @@ func newValidateCommandResult(targetCtx *target_context.TargetContext, startTime
 		})
 	}
 
-	clusterInfo, err := buildClusterInfo(targetCtx.SharedContext.K)
-	if err != nil {
-		r.Errors = append(r.Errors, result.DeploymentError{
-			Message: err.Error(),
-		})
-	}
-
 	r.TargetKey.TargetName = targetCtx.Target.Name
 	r.TargetKey.Discriminator = targetCtx.Target.Discriminator
-	r.TargetKey.ClusterId = clusterInfo.ClusterId
+
+	if targetCtx.SharedContext.K != nil {
+		clusterInfo := buildClusterInfo(targetCtx.SharedContext.K, &r.Warnings)
+		r.TargetKey.ClusterId = clusterInfo.ClusterId
+	}
 
 	return r
 }
@@ -95,14 +90,9 @@ func newDeleteCommandResult(k *k8s2.K8sCluster, startTime time.Time, inclusion *
 	r.Command.IncludeDeploymentDirs = inclusion.GetIncludes("deploymentItemDir")
 	r.Command.ExcludeDeploymentDirs = inclusion.GetExcludes("deploymentItemDir")
 
-	var err error
-	r.ClusterInfo, err = buildClusterInfo(k)
-	if err != nil {
-		r.Errors = append(r.Errors, result.DeploymentError{
-			Message: err.Error(),
-		})
+	if k != nil {
+		r.ClusterInfo = buildClusterInfo(k, &r.Warnings)
 	}
-
 	return r
 }
 
@@ -121,14 +111,19 @@ func finishValidateResult(r *result.ValidateResult, targetCtx *target_context.Ta
 	r.EndTime = metav1.Now()
 }
 
-func buildClusterInfo(k *k8s2.K8sCluster) (result.ClusterInfo, error) {
+func buildClusterInfo(k *k8s2.K8sCluster, warnings *[]result.DeploymentError) result.ClusterInfo {
 	var clusterInfo result.ClusterInfo
 	clusterId, err := k.GetClusterId()
-	if err != nil {
-		return clusterInfo, err
-	}
 	clusterInfo = result.ClusterInfo{
 		ClusterId: clusterId,
 	}
-	return clusterInfo, nil
+	if err == nil {
+		return clusterInfo
+	}
+	if !errors.IsForbidden(err) {
+		*warnings = append(*warnings, result.DeploymentError{
+			Message: err.Error(),
+		})
+	}
+	return clusterInfo
 }
