@@ -12,11 +12,11 @@ type LoadedKluctlProject struct {
 	LoadArgs LoadKluctlProjectArgs
 	LoadTime time.Time
 
-	SealedSecretsDir string
-
 	Config  types2.KluctlProject
 	Targets []*types2.Target
 
+	NoNameTarget *types2.Target
+
 	J2    *jinja2.Jinja2
 	GitRP *repocache.GitRepoCache
 	OciRP *repocache.OciRepoCache
