@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"github.com/huandu/xstrings"
+	gittypes "github.com/kluctl/kluctl/lib/git/types"
 	test_utils "github.com/kluctl/kluctl/v2/e2e/test-utils"
 	"github.com/kluctl/kluctl/v2/pkg/clouds/aws"
 	"github.com/kluctl/kluctl/v2/pkg/clouds/gcp"
@@ -21,8 +22,8 @@ import (
 	"github.com/getsops/sops/v3/age"
 	git2 "github.com/go-git/go-git/v5"
 	"github.com/go-git/go-git/v5/plumbing"
-	"github.com/kluctl/kluctl/v2/pkg/git/auth"
-	ssh_pool "github.com/kluctl/kluctl/v2/pkg/git/ssh-pool"
+	"github.com/kluctl/kluctl/lib/git/auth"
+	ssh_pool "github.com/kluctl/kluctl/lib/git/ssh-pool"
 	"github.com/kluctl/kluctl/v2/pkg/k8s"
 	"github.com/kluctl/kluctl/v2/pkg/repocache"
 	"github.com/kluctl/kluctl/v2/pkg/types"
@@ -127,6 +128,19 @@ func (s *VarsLoaderTestSuite) TestValuesNoOverrides() {
 	})
 }
 
+func (s *VarsLoaderTestSuite) TestValuesTargetPath() {
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			Values:     uo.FromStringMust(`{"test1": {"test2": 42}}`),
+			TargetPath: "my.target",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedInt("my", "target", "test1", "test2")
+		assert.Equal(s.T(), int64(42), v)
+	})
+}
+
 func (s *VarsLoaderTestSuite) TestWhen() {
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
@@ -157,7 +171,7 @@ func (s *VarsLoaderTestSuite) TestFile() {
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		vs := &types.VarsSource{
-			File: utils.StrPtr("test.yaml"),
+			File: utils.Ptr("test.yaml"),
 		}
 		err := vl.LoadVars(context.TODO(), vc, vs, []string{d}, "")
 		assert.NoError(s.T(), err)
@@ -171,7 +185,7 @@ func (s *VarsLoaderTestSuite) TestFile() {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
-			File:          utils.StrPtr("test.yaml"),
+			File:          utils.Ptr("test.yaml"),
 		}, []string{d}, "")
 		assert.NoError(s.T(), err)
 
@@ -183,7 +197,7 @@ func (s *VarsLoaderTestSuite) TestFile() {
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
-			File:          utils.StrPtr("test-missing.yaml"),
+			File:          utils.Ptr("test-missing.yaml"),
 		}, []string{d}, "")
 		assert.NoError(s.T(), err)
 	})
@@ -199,7 +213,7 @@ func (s *VarsLoaderTestSuite) TestSopsFile() {
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		vs := &types.VarsSource{
-			File: utils.StrPtr("test.yaml"),
+			File: utils.Ptr("test.yaml"),
 		}
 		err := vl.LoadVars(context.TODO(), vc, vs, []string{d}, "")
 		assert.NoError(s.T(), err)
@@ -217,7 +231,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoad() {
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
-			File: utils.StrPtr("test.yaml"),
+			File: utils.Ptr("test.yaml"),
 		}, []string{d}, "")
 		assert.NoError(s.T(), err)
 
@@ -234,7 +248,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoadSubDir() {
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
-			File: utils.StrPtr("test.yaml"),
+			File: utils.Ptr("test.yaml"),
 		}, []string{d, filepath.Join(d, "subdir")}, "")
 		assert.NoError(s.T(), err)
 
@@ -249,7 +263,7 @@ func (s *VarsLoaderTestSuite) TestFileWithLoadNotExists() {
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
-			File: utils.StrPtr("test.yaml"),
+			File: utils.Ptr("test.yaml"),
 		}, []string{d}, "")
 		assert.EqualError(s.T(), err, "failed to render vars file test.yaml: template test3.txt not found")
 	})
@@ -266,7 +280,7 @@ func (s *VarsLoaderTestSuite) TestGit() {
 	}, "")
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
-		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
+		url, _ := gittypes.ParseGitUrl(gs.GitRepoUrl("repo"))
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Git: &types.VarsSourceGit{
 				Url:  *url,
@@ -280,7 +294,7 @@ func (s *VarsLoaderTestSuite) TestGit() {
 	})
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
-		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
+		url, _ := gittypes.ParseGitUrl(gs.GitRepoUrl("repo"))
 		b := true
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			IgnoreMissing: &b,
@@ -317,12 +331,12 @@ func (s *VarsLoaderTestSuite) TestGitBranch() {
 	assert.NoError(s.T(), err)
 
 	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
-		url, _ := types.ParseGitUrl(gs.GitRepoUrl("repo"))
+		url, _ := gittypes.ParseGitUrl(gs.GitRepoUrl("repo"))
 		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Git: &types.VarsSourceGit{
 				Url:  *url,
 				Path: "test.yaml",
-				Ref:  &types.GitRef{Branch: "testbranch"},
+				Ref:  &gittypes.GitRef{Branch: "testbranch"},
 			},
 		}, nil, "")
 		assert.NoError(s.T(), err)
@@ -546,6 +560,363 @@ func (s *VarsLoaderTestSuite) TestK8sObjectLabels() {
 	})
 }
 
+func (s *VarsLoaderTestSuite) TestClusterObject() {
+	s.createNamespace()
+
+	cm1 := corev1.ConfigMap{
+		ObjectMeta: v1.ObjectMeta{
+			Name:      "cm1",
+			Namespace: s.namespace(),
+			Labels: map[string]string{
+				"label1":    "lv1",
+				"label2":    "42",
+				"label3":    "x",
+				"namespace": s.namespace(),
+			},
+			Annotations: map[string]string{
+				"yaml":          `{"x": 45}`,
+				"render":        `{{ my.target.a }}`,
+				"renderAndYaml": `{"a": {{ my.target.b.x * 2 }} }`,
+			},
+		},
+		Data: map[string]string{},
+	}
+	cm2 := corev1.ConfigMap{
+		ObjectMeta: v1.ObjectMeta{
+			Name:      "cm2",
+			Namespace: s.namespace(),
+			Labels: map[string]string{
+				"label1":    "lv2",
+				"label2":    "44",
+				"label3":    "x",
+				"namespace": s.namespace(),
+			},
+			Annotations: map[string]string{
+				"a1": "v1",
+				"a2": `{{ 1 + 2 }}`,
+			},
+		},
+		Data: map[string]string{},
+	}
+
+	err := s.k.Client.Create(context.TODO(), &cm1)
+	assert.NoError(s.T(), err)
+	err = s.k.Client.Create(context.TODO(), &cm2)
+	assert.NoError(s.T(), err)
+
+	// test path
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `$`,
+			},
+			TargetPath: "my.target2",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels.*`,
+			},
+			TargetPath: "my.target3",
+		}, nil, "")
+		assert.ErrorContains(s.T(), err, "json path resulted in multiple matches")
+
+		v, _, _ := vc.Vars.GetNestedString("my", "target")
+		assert.Equal(s.T(), "42", v)
+
+		v, _, _ = vc.Vars.GetNestedString("my", "target2", "apiVersion")
+		assert.Equal(s.T(), "v1", v)
+	})
+
+	// test targetPath
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+		}, nil, "")
+		assert.ErrorContains(s.T(), err, `'targetPath' is required for this variable source`)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedString("my", "target")
+		assert.Equal(s.T(), "42", v)
+	})
+
+	// test targetPath with multiple matches
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		vc.Update(uo.FromMap(map[string]interface{}{
+			"list": []map[string]any{
+				{
+					"x": map[string]any{},
+				},
+				{
+					"x": map[string]any{},
+				},
+			},
+		}))
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "list[*].x.y",
+		}, nil, "")
+		assert.ErrorContains(s.T(), err, `can not deduce what element to add at 'list'`)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "list[0].x.y",
+		}, nil, "")
+		assert.ErrorContains(s.T(), err, `can not follow a <nil> at 'list[0]'`)
+	})
+
+	// test apiVersion
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:       "ConfigMap",
+				ApiVersion: "v1",
+				Name:       "cm1",
+				Namespace:  s.namespace(),
+				Path:       `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedString("my", "target")
+		assert.Equal(s.T(), "42", v)
+	})
+
+	// test labels
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind: "ConfigMap",
+				Labels: map[string]string{
+					"label1": "lv1",
+				},
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.a",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind: "ConfigMap",
+				Labels: map[string]string{
+					"label1": "lv2",
+				},
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.b",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind: "ConfigMap",
+				Labels: map[string]string{
+					"label3": "x",
+				},
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.b",
+		}, nil, "")
+		assert.ErrorContains(s.T(), err, "found more than one object")
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind: "ConfigMap",
+				Labels: map[string]string{
+					"label3": "x",
+				},
+				List:      true,
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.c",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind: "ConfigMap",
+				Labels: map[string]string{
+					"namespace": s.namespace(),
+				},
+				List: true,
+				// no namespace
+				Path: `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.d",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedString("my", "target", "a")
+		assert.Equal(s.T(), "42", v)
+		v, _, _ = vc.Vars.GetNestedString("my", "target", "b")
+		assert.Equal(s.T(), "44", v)
+		l, _, _ := vc.Vars.GetNestedStringList("my", "target", "c")
+		assert.Equal(s.T(), []string{"42", "44"}, l)
+		l, _, _ = vc.Vars.GetNestedStringList("my", "target", "d")
+		assert.Equal(s.T(), []string{"42", "44"}, l)
+	})
+
+	// test render
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.a",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.annotations["render"]`,
+			},
+			TargetPath: "my.target.b",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.annotations["render"]`,
+				Render:    true,
+			},
+			TargetPath: "my.target.c",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm2",
+				Namespace: s.namespace(),
+				Path:      `metadata.annotations`,
+				Render:    true,
+			},
+			TargetPath: "my.target.d",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedString("my", "target", "a")
+		assert.Equal(s.T(), "42", v)
+		v, _, _ = vc.Vars.GetNestedString("my", "target", "b")
+		assert.Equal(s.T(), `{{ my.target.a }}`, v)
+		v, _, _ = vc.Vars.GetNestedString("my", "target", "c")
+		assert.Equal(s.T(), "42", v)
+		x, _, _ := vc.Vars.GetNestedField("my", "target", "d")
+		assert.Equal(s.T(), map[string]any{
+			"a1": "v1",
+			"a2": "3",
+		}, x)
+	})
+
+	// test parseYaml
+	s.testVarsLoader(func(vl *VarsLoader, vc *VarsCtx, aws *aws.FakeAwsClientFactory, gcp *gcp.FakeClientFactory) {
+		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.labels["label2"]`,
+			},
+			TargetPath: "my.target.a",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.annotations["yaml"]`,
+				ParseYaml: true,
+			},
+			TargetPath: "my.target.b",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
+			ClusterObject: &types.VarsSourceClusterObject{
+				Kind:      "ConfigMap",
+				Name:      "cm1",
+				Namespace: s.namespace(),
+				Path:      `metadata.annotations["renderAndYaml"]`,
+				Render:    true,
+				ParseYaml: true,
+			},
+			TargetPath: "my.target.c",
+		}, nil, "")
+		assert.NoError(s.T(), err)
+
+		v, _, _ := vc.Vars.GetNestedString("my", "target", "a")
+		assert.Equal(s.T(), "42", v)
+		x, _, _ := vc.Vars.GetNestedField("my", "target", "b")
+		assert.Equal(s.T(), uo.FromMap(map[string]any{
+			"x": float64(45),
+		}), x)
+		x, _, _ = vc.Vars.GetNestedField("my", "target", "c")
+		assert.Equal(s.T(), uo.FromMap(map[string]any{
+			"a": float64(90),
+		}), x)
+	})
+}
+
 func (s *VarsLoaderTestSuite) TestSystemEnv() {
 	s.T().Setenv("TEST1", "42")
 	s.T().Setenv("TEST2", "'43'")
@@ -700,7 +1071,7 @@ func (s *VarsLoaderTestSuite) TestHttp_POST() {
 		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Http: &types.VarsSourceHttp{
 				Url:    types.YamlUrl{URL: *u},
-				Method: utils.StrPtr("POST"),
+				Method: utils.Ptr("POST"),
 			},
 		}, nil, "")
 		assert.ErrorContains(s.T(), err, "failed with status code 543")
@@ -708,8 +1079,8 @@ func (s *VarsLoaderTestSuite) TestHttp_POST() {
 		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Http: &types.VarsSourceHttp{
 				Url:    types.YamlUrl{URL: *u},
-				Method: utils.StrPtr("POST"),
-				Body:   utils.StrPtr("body"),
+				Method: utils.Ptr("POST"),
+				Body:   utils.Ptr("body"),
 			},
 		}, nil, "")
 		assert.ErrorContains(s.T(), err, "failed with status code 544")
@@ -717,8 +1088,8 @@ func (s *VarsLoaderTestSuite) TestHttp_POST() {
 		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Http: &types.VarsSourceHttp{
 				Url:     types.YamlUrl{URL: *u},
-				Method:  utils.StrPtr("POST"),
-				Body:    utils.StrPtr("body"),
+				Method:  utils.Ptr("POST"),
+				Body:    utils.Ptr("body"),
 				Headers: map[string]string{"h": "h"},
 			},
 		}, nil, "")
@@ -740,7 +1111,7 @@ func (s *VarsLoaderTestSuite) TestHttp_JsonPath() {
 		err := vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			Http: &types.VarsSourceHttp{
 				Url:      types.YamlUrl{URL: *u},
-				JsonPath: utils.StrPtr("test1"),
+				JsonPath: utils.Ptr("test1"),
 			},
 		}, nil, "")
 		assert.NoError(s.T(), err)
@@ -766,7 +1137,7 @@ func (s *VarsLoaderTestSuite) TestAwsSecretsManager() {
 		err = vl.LoadVars(context.TODO(), vc, &types.VarsSource{
 			AwsSecretsManager: &types.VarsSourceAwsSecretsManager{
 				SecretName: "secret",
-				Region:     utils.StrPtr("eu-central1"),
+				Region:     utils.Ptr("eu-central1"),
 			},
 		}, nil, "")
 		assert.NoError(s.T(), err)
@@ -801,7 +1172,7 @@ func (s *VarsLoaderTestSuite) TestAwsSecretsManager() {
 			IgnoreMissing: &b,
 			AwsSecretsManager: &types.VarsSourceAwsSecretsManager{
 				SecretName: "missing",
-				Region:     utils.StrPtr("eu-central1"),
+				Region:     utils.Ptr("eu-central1"),
 			},
 		}, nil, "")
 		assert.NoError(s.T(), err)
